@@ -41,7 +41,6 @@ from igraph._igraph import (
     BLISS_FSM,
     DFSIter,
     Edge,
-    EdgeSeq as _EdgeSeq,
     GET_ADJACENCY_BOTH,
     GET_ADJACENCY_LOWER,
     GET_ADJACENCY_UPPER,
@@ -62,7 +61,6 @@ from igraph._igraph import (
     TREE_OUT,
     TREE_UNDIRECTED,
     Vertex,
-    VertexSeq as _VertexSeq,
     WEAK,
     arpack_options as default_arpack_options,
     community_to_membership,
@@ -260,13 +258,8 @@ from igraph.structural import (
 )
 from igraph.summary import GraphSummary, summary
 from igraph.utils import (
-    dbl_epsilon,
-    multidict,
-    named_temporary_file,
     numpy_to_contiguous_memoryview,
     rescale,
-    safemin,
-    safemax,
 )
 from igraph.version import __version__, __version_info__
 
@@ -1126,37 +1119,86 @@ del (
 # except for the objects mentioned down here.
 __all__ = (
     'config',
+    'AdvancedGradientPalette',
+    'BoundingBox',
+    'CairoGraphDrawer',
+    'ClusterColoringPalette',
+    'Clustering',
+    'CohesiveBlocks',
+    'Configuration',
+    'Cover',
     'Cut',
+    'DefaultGraphDrawer',
+    'Dendrogram',
+    'DyadCensus',
+    'Edge',
+    'EdgeSeq',
+    'FittedPowerLaw',
+    'Flow',
+    'GradientPalette',
     'Graph',
     'GraphBase',
-    'Edge',
-    'Vertex',
-    'EdgeSeq',
-    'VertexSeq',
-    'Matching',
-    'AdvancedGradientPalette',
-    'GradientPalette',
+    'GraphSummary',
+    'Histogram',
     'InternalError',
     'Layout',
-    'default_arpack_options',
+    'Matching',
+    'MatplotlibGraphDrawer',
+    'Matrix',
+    'Palette',
+    'Plot',
+    'Point',
+    'PrecalculatedPalette',
+    'RainbowPalette',
+    'Rectangle',
+    'RunningMean',
+    'TriadCensus',
+    'UniqueIdGenerator',
+    'Vertex',
+    'VertexClustering',
+    'VertexCover',
+    'VertexDendrogram',
+    'VertexSeq',
+    'autocurve',
+    'color_name_to_rgb',
+    'color_name_to_rgba',
     'community_to_membership',
+    'compare_communities',
     'convex_hull',
-    'is_degree_sequence',
-    'is_graphical_degree_sequence',
+    'default_arpack_options',
+    'disjoint_union',
+    'get_include',
     'hsla_to_rgba',
     'hsl_to_rgb',
     'hsva_to_rgba',
     'hsv_to_rgb',
+    'is_degree_sequence',
+    'is_graphical',
+    'is_graphical_degree_sequence',
+    'intersection',
+    'known_colors',
+    'load',
+    'mean',
+    'median',
+    'palettes',
+    'percentile',
+    'plot',
+    'power_law_fit',
+    'quantile',
+    'read',
+    'rescale',
     'rgba_to_hsla',
     'rgb_to_hsl',
     'rgba_to_hsva',
     'rgb_to_hsv',
+    'save',
     'set_progress_handler',
     'set_random_number_generator',
     'set_status_handler',
+    'split_join_distance',
+    'summary',
     'union',
-    'intersection',
-    'disjoint_union',
+    'write',
 
     # enums and stuff
     'ADJ_DIRECTED',
